<?php

add_action( 'init',  function(){
    if ( ! function_exists( 'register_block_type' ) ) {
        return;
    }
    if(!function_exists('civi_wp')){
        add_action( 'admin_notices', function(){
            echo '<div class="notice notice-warning"><p>'.__('Activating blocks for CiviCRM without CiviCRM does not make sens.', 'blocks-for-civicrm').'</p></div>';
        });
    }
    if (!civi_wp()->initialize()) {
        return;
    }

    wp_register_script(
        'block-civicrm',
        plugins_url('assets/built/js/block-civicrm.min.js', __DIR__ ),
        ['wp-blocks', 'wp-element', 'wp-editor', 'wp-components', 'wp-i18n', 'wp-core-data'],
        filemtime(plugin_dir_path(__DIR__).'assets/built/js/block-civicrm.min.js')
    );

    register_block_type( 'blocks-for-civicrm/civicrm', array(
        'editor_script' => 'block-civicrm',
        'render_callback' => 'block_civicrm',
    ) );
} );

add_action ('enqueue_block_editor_assets', function(){
    if (!civi_wp()->initialize()) {
        return;
    }
    $CRM_Core_Form_ShortCode = new CRM_Core_Form_ShortCode();
    $CRM_Core_Form_ShortCode->preProcess();
    $components = $CRM_Core_Form_ShortCode->components;
    $options = $CRM_Core_Form_ShortCode->options;

    $id_options = [];
    if(function_exists('civicrm_api3')){
        foreach($components as $component_id=>$component){
            if($component['select'] !== null){
                $id_options[$component_id] = [
                    [
                        'label' => '',
                        'value' => '',
                    ],
                ];
                $idSelect = $component['select'];
                $api_data = [
                    'return'=>'id, title',
                ];
                $result = civicrm_api3($idSelect['entity'], 'get', $api_data);
                if($result['count']){
                    foreach ($result['values'] as $item) {
                        $id_options[$component_id][] = [
                            'label' => $item['title'],
                            'value' => $item['id'],
                        ];
                    }
                }
            }
        }
    }

    $option_labels = [
        'gid'=>__('Profile', 'blocks-for-civicrm'),
        'cid'=>__('Contact', 'blocks-for-civicrm'),
        'id'=>__('Page', 'blocks-for-civicrm'),
        'hijack'=>__('Hijack', 'blocks-for-civicrm'),
        'mode'=>__('Mode', 'blocks-for-civicrm'),
        'action'=>__('Action', 'blocks-for-civicrm'),
    ];
    foreach ($options as $option) {
        $option_labels[$option['key']] = __(ucfirst($option['key']), 'blocks-for-civicrm');
    }

    wp_localize_script('block-civicrm', 'block_civicrm', [
        'i18n' => [
            'title'=>__('CiviCRM component', 'blocks-for-civicrm'),
            'description'=>__('Block for CiviCRM', 'blocks-for-civicrm'),
            'component'=>__('Component', 'blocks-for-civicrm'),
            'options'=>$option_labels,
        ],
        'components' => $components,
        'options' => $options,
        'id_options' => $id_options,
    ]);
});

function block_civicrm($attributes, $content=''){
    if(is_admin()){
        return 'civicrm preview';
    }
    return civi_wp()->shortcodes->render_single($attributes);
}
